@@ -1,15 +1,12 @@
-import http
 import json
-import http.client
-import ssl
-import time
-import requests
-from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.util.retry import Retry
 import logging
 import os
 import time
+
+import requests
 from PyInquirer import style_from_dict, Token, prompt
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.util.retry import Retry
 
 LOGLEVEL = os.environ.get("LOGLEVEL", "INFO")
 
